@@ -32,4 +32,18 @@ static inline int dma_set_mask_and_coherent(struct device *dev, u64 mask)
 }
 #endif /* LINUX_VERSION_IS_LESS(3,13,0) */
 
+#ifndef DMA_MAPPING_ERROR
+/*
+ * A dma_addr_t can hold any valid DMA or bus address for the platform.  It can
+ * be given to a device to use as a DMA source or target.  It is specific to a
+ * given device and there may be a translation between the CPU physical address
+ * space and the bus address space.
+ *
+ * DMA_MAPPING_ERROR is the magic error code if a mapping failed.  It should not
+ * be used directly in drivers, but checked for using dma_mapping_error()
+ * instead.
+ */
+#define DMA_MAPPING_ERROR		(~(dma_addr_t)0)
+#endif /* DMA_MAPPING_ERROR */
+
 #endif /* __BACKPORT_LINUX_DMA_MAPPING_H */
