@@ -113,4 +113,14 @@ void backport_thermal_zone_device_unregister(struct thermal_zone_device *);
 #endif /* ! < 3.8.0 */
 #endif /* CONFIG_THERMAL */
 
+#if LINUX_VERSION_IS_LESS(5,9,0)
+#define thermal_zone_device_enable LINUX_BACKPORT(thermal_zone_device_enable)
+static inline int thermal_zone_device_enable(struct thermal_zone_device *tz)
+{ return 0; }
+
+#define thermal_zone_device_disable LINUX_BACKPORT(thermal_zone_device_disable)
+static inline int thermal_zone_device_disable(struct thermal_zone_device *tz)
+{ return 0; }
+#endif /* < 5.9 */
+
 #endif /* __BACKPORT_LINUX_THERMAL_H */
